class EmployerRecordsController < ApplicationController
  before_action :set_employer_record, only: [:edit, :update]

  def edit
    # Logic to edit an EmployerRecord
    # Display a form to edit the EmployerRecord
  end

  def update
    # Logic to update an EmployerRecord
    # Called when the edit form is submitted
    if @employer_record.update(employer_record_params)
      redirect_to employer_path(@employer_record.employer), notice: 'Employer record was successfully updated.'
    else
      render :edit
    end
  end

  def link_participant_to_employer
    # Assuming you have the employer and participant IDs
    employer_id = params[:employer_id]
    participant_id = params[:participant_id]
  
    employer_record = EmployerRecord.new(employer_id: employer_id, participant_id: participant_id, start_date: Date.today)
  
    if employer_record.save
      # Redirect or render success message
    else
      # Handle error
    end
  end

  def link_participant
    @employer_record = EmployerRecord.new(employer_record_params)
    if @employer_record.save
      redirect_to employer_path(@employer_record.employer), notice: 'Participant was successfully linked.'
    else
      render 'show' # Or where you want to redirect in case of failure
    end
  end

  
  def destroy
    @employer_record = EmployerRecord.find_by(id: params[:id])
    employer_id = @employer_record&.employer_id
  
    if @employer_record
      @employer_record.destroy
      redirect_to employer_path(employer_id), notice: 'Employer record was successfully deleted.'
    else
      # Providing a more descriptive alert message
      alert_message = "Unable to find the employer record. It may have already been deleted or does not exist."
      redirect_to employer_path(employer_id), alert: alert_message
    end
  end
  
  

  private

  def set_employer_record
    @employer_record = EmployerRecord.find(params[:id])
  end

  def employer_record_params
    params.require(:employer_record).permit(:employer_id, :participant_id, :start_date, :end_date)
  end
end
